// content.js
(function () {
  function formatFilename(url, frameNumber) {
    const match = url.match(/\/event\/([^/]+)\/archive\/live/);
    const eventName = match ? match[1] : "screenshot";
    return `${eventName}_${frameNumber}.png`;
  }

  function getVideoElement() {
    return document.querySelector("video");
  }

  function captureFrame(video) {
    const canvas = document.createElement("canvas");
    canvas.width = 1920;
    canvas.height = 1080;
    const ctx = canvas.getContext("2d");
    ctx.drawImage(video, 0, 0, canvas.width, canvas.height);
    return canvas.toDataURL("image/png");
  }

  function downloadImage(dataUrl, filename) {
    const a = document.createElement("a");
    a.href = dataUrl;
    a.download = filename;
    document.body.appendChild(a);
    a.click();
    document.body.removeChild(a);
  }

  document.addEventListener("keydown", (e) => {
    if (e.key === "q") {
      const video = getVideoElement();
      if (video) {
        const currentTimeMs = Math.floor(video.currentTime * 1000);
        console.log("現在の時間:", video.currentTime);
        console.log("計算されたフレーム番号 (currentTime * 1000):", currentTimeMs);

        const filename = formatFilename(location.href, currentTimeMs);
        const dataUrl = captureFrame(video);

        // Chrome/EdgeとFirefox対応
        if (typeof browser !== "undefined" && browser.downloads) {
          // Firefox
          browser.runtime.sendMessage({
            action: "download",
            dataUrl,
            filename,
          });
        } else if (typeof chrome !== "undefined" && chrome.runtime) {
          // Chrome / Edge
          chrome.runtime.sendMessage({
            action: "download",
            dataUrl,
            filename,
          });
        } else {
          // fallback
          downloadImage(dataUrl, filename);
        }
      }
    }
  });
})();
