chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  console.log("メッセージ受信: ", message);

  if (message.type === "downloadImage") {
    console.log("ダウンロード処理開始: ", message.filename);

    try {
      const base64Data = message.url.split(',')[1];
      const mimeType = message.url.match(/^data:(.*?);base64,/)[1];
      const binary = atob(base64Data);
      const array = Uint8Array.from(binary, char => char.charCodeAt(0));
      const blob = new Blob([array], { type: mimeType });
      const objectUrl = URL.createObjectURL(blob);

      // Firefox向け: callback形式
      chrome.downloads.download({
        url: objectUrl,
        filename: message.filename,
        saveAs: false
      }, (downloadId) => {
        if (chrome.runtime.lastError) {
          console.error("ダウンロードエラー:", chrome.runtime.lastError);
          sendResponse({ success: false, error: chrome.runtime.lastError.message });
        } else {
          console.log("ダウンロード成功:", downloadId);
          sendResponse({ success: true });
        }

        // Object URL 解放
        setTimeout(() => URL.revokeObjectURL(objectUrl), 10000);
      });
    } catch (err) {
      console.error("Blob変換またはダウンロード中にエラー:", err);
      sendResponse({ success: false, error: err.message });
    }

    return true; // 非同期応答のため
  }
});
