(function () {
  document.addEventListener("keydown", async function (e) {
    if (e.key.toLowerCase() === "q") {
      const video = document.querySelector("video");
      if (!video) {
        console.warn("ビデオ要素が見つかりませんでした");
        return;
      }

      const canvas = document.createElement("canvas");
      canvas.width = video.videoWidth;
      canvas.height = video.videoHeight;
      const ctx = canvas.getContext("2d");
      ctx.drawImage(video, 0, 0, canvas.width, canvas.height);

      const imageDataUrl = canvas.toDataURL("image/png");

      const currentTime = video.currentTime;
      console.log("現在の時間:", currentTime);

      const frameNumber = Math.floor(currentTime * 1000);
      console.log("計算されたフレーム番号 (currentTime * 1000):", frameNumber);

      // URL からイベントIDを取得
      const match = location.href.match(/\/event\/([^/]+)\/archive\//);
      const eventId = match ? match[1] : "unknown";

      // ファイル名にイベントIDを組み込む
      const filename = `${eventId}_${frameNumber}.png`;

      try {
        const response = await chrome.runtime.sendMessage({
          type: "downloadImage",
          url: imageDataUrl,
          filename: filename,
        });

        if (response?.success) {
          console.log("✅ ダウンロード成功！");
        } else {
          console.error("❌ ダウンロード失敗:", response?.error);
        }
      } catch (err) {
        console.error("❌ 送信時にエラー:", err);
      }
    }
  });
})();
